<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ms">
<context>
    <name>AptConfigMessage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="85"/>
        <source>Enter the number to configure: </source>
        <translation>Masukkan bilangan konfigur:</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="90"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>BackendProcessPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="18"/>
        <source>Loading packages...</source>
        <translation>Memuatkan pakej...</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="19"/>
        <source>%1/%2 loaded</source>
        <translation>%1/%2 dimuatkan</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="22"/>
        <source>Initializing...</source>
        <translation>Memulakan...</translation>
    </message>
</context>
<context>
    <name>DdimErrorPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/ddimerrorpage.cpp" line="18"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="118"/>
        <source>Package Installer</source>
        <translation>Pemasang Pakej</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="128"/>
        <source>Settings</source>
        <translation>Tetapan</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="695"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="819"/>
        <source>Installing other packages... Please open it later.</source>
        <translation>Memasang pakej lain... Sila buka ia kemudian.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="700"/>
        <source>Parsing failed: An illegal file structure was found in the manifest file!</source>
        <translation>Gagal dihurai: Satu struktur fail tidak sah telah ditemui dalam fail manifes!</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="702"/>
        <source>Parsing failed: An illegal version number was found in the manifest file!</source>
        <translation>Gagal dihurai: Satu nombor versi tidak sah telah ditemui dalam fail manife!</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="704"/>
        <source>No deb packages found. Please check the folder.</source>
        <translation>Tiada pakej deb ditemui. Sila periksa folder.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="842"/>
        <source>The %1 package may be broken</source>
        <translation>Pakej %1 mungkin rosak</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="851"/>
        <source>You can only install local %1 packages</source>
        <translation>Anda hanya boleh memasang pakej %1 yang lokasl</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="860"/>
        <source>No permission to access this folder</source>
        <translation>Tiada kebenaran untuk mengakses folder ini</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="877"/>
        <source>Already Added</source>
        <translation>Sudah Ditambah</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="886"/>
        <source>%1 does not exist, please reselect</source>
        <translation>%1 tidak wujud, sila pilih semula</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="445"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="894"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="1047"/>
        <source>Bulk Install</source>
        <translation>Pasang Pukal</translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="104"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="127"/>
        <source>Installation failed, please check your network connection</source>
        <translation>Pemasangan gagal, sila periksa sambungan rangkaian anda</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="108"/>
        <source>Installation failed, please check for updates in Control Center</source>
        <translation>Pemasangan gagal, sila periksa kemas kini dalam Pusat Kawalan</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="111"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="117"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="133"/>
        <source>Installation failed, insufficient disk space</source>
        <translation>Pemasangan gagal, ruang cakera tidak mencukupi</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="139"/>
        <source>No digital signature</source>
        <translation>Tiada tandatangan digital</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="144"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="895"/>
        <source>Invalid digital signature</source>
        <translation>Tandatangan digital tidak sah</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="152"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="880"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1981"/>
        <source>The administrator has set policies to prevent installation of this package</source>
        <translation>Pentadbir telah menetapkan dasar yang menghalang pemasangan pakej ini</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="159"/>
        <source>Installation Failed</source>
        <translation>Pemasangan Gagal</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="863"/>
        <source>current system</source>
        <translation>sistem semasa</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="866"/>
        <source>%2 has been installed in %1, please uninstall this package before installing it</source>
        <translation>%2 telah dipasang dalam %1, sila unistall pakej ini sebelum memasangnya</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="873"/>
        <source>Broken dependencies, try installing the app in compatibility mode</source>
        <translation>Pendependen yang rosak, cuba pasang aplikasi dalam mod kompatibiliti</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="876"/>
        <source>Compatibility mode installation failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="898"/>
        <source>Failed to install %1</source>
        <translation>Gagal memasang %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1328"/>
        <source>Unable to install - no digital signature</source>
        <translation>Tidak dapat pasang - tiada tandatangan digital</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1329"/>
        <source>Please go to Control Center to enable developer mode and try again. Proceed?</source>
        <translation>Sila pergi ke Pusat Kawalan untuk membenarkan mod pembangun dan cuba sekali lagi. Teruskan?</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1332"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Batal</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1333"/>
        <source>Proceed</source>
        <comment>button</comment>
        <translation>Teruskan</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1280"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1394"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1983"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1284"/>
        <source>Failed to install %1: no valid digital signature</source>
        <translation>Gagal memasang %1: tiada tandatangan digital yang sah</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1435"/>
        <source>This package does not have a valid digital signature. Continue with the installation?</source>
        <translation>Pakej ini tidak memiliki tandatangan digital yang sah. Teruskan pemasangan?</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1437"/>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1438"/>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Teruskan</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1278"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1391"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1980"/>
        <source>Unable to install</source>
        <translation>Tidak boleh memasang</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1392"/>
        <source>This package does not have a valid digital signature</source>
        <translation>Pakej ini tidak memiliki tandatangan digital yang sah</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="902"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="908"/>
        <source>Broken dependencies: %1</source>
        <translation>Dependensi rosak: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="149"/>
        <source>Authentication failed</source>
        <translation>Pengesahihan gagal</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="834"/>
        <source>Unmatched package architecture</source>
        <translation>Senibina pakej tidak sepadan</translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../src/deb-installer/view/widgets/filechoosewidget.cpp" line="51"/>
        <source>Drag deb packages here</source>
        <translation>Seret pakej-pakej deb di sini</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/filechoosewidget.cpp" line="93"/>
        <source>Select File</source>
        <translation>Pilih Fail</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="35"/>
        <source>Show details</source>
        <translation>Tunjuk perincian</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="35"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>Kuncup</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="179"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>Pasang</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="180"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>Selesai</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="182"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>Undur</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="545"/>
        <source>Install %1 will remove: </source>
        <translation>Pemasangan %1 akan menghapuskan: </translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="563"/>
        <source>Dependencies in the repository</source>
        <translation>Dependensi dalam repositori</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="570"/>
        <source>Missing dependencies</source>
        <translation>Dependensi hilang</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="629"/>
        <source>Installing dependencies: %1</source>
        <translation>Memasang dependensi: %1</translation>
    </message>
</context>
<context>
    <name>PackageSelectItem</name>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="87"/>
        <source>Same version installed</source>
        <translation>Versi serupa telah dipasang</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="91"/>
        <source>Earlier version installed: %1</source>
        <translation>Versi lebih awal dipasang: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="96"/>
        <source>Later version installed: %1</source>
        <translation>Versi terkemudian dipasang: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="102"/>
        <source>Unmatched package architecture</source>
        <translation>Senibina pakej tidak sepadan</translation>
    </message>
</context>
<context>
    <name>PackageSelectView</name>
    <message>
        <location filename="../src/deb-installer/view/pages/packageselectview.cpp" line="23"/>
        <source>Select all</source>
        <translation>Pilih semua</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/packageselectview.cpp" line="24"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>Pasang</translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="62"/>
        <source>Installing</source>
        <translation>Memasang</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="66"/>
        <source>Installed</source>
        <translation>Dipasang</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="74"/>
        <source>Failed</source>
        <translation>Gagal</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="70"/>
        <source>Waiting</source>
        <translation>Menunggu</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="246"/>
        <source>Same version installed</source>
        <translation>Versi serupa telah dipasang</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="248"/>
        <source>Later version installed: %1</source>
        <translation>Versi terkemudian dipasang: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="250"/>
        <source>Earlier version installed: %1</source>
        <translation>Versi lebih awal dipasang: %1</translation>
    </message>
</context>
<context>
    <name>PackagesListView</name>
    <message>
        <location filename="../src/deb-installer/model/packagelistview.cpp" line="189"/>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="32"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="50"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="52"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>Kuncup</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="9"/>
        <source>Basic</source>
        <translation>Asas</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="10"/>
        <source>Check digital signatures if the developer mode is enabled</source>
        <translation>Periksa tandatangan digital jika mod pembangun dibenarkan</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/settingdialog.cpp" line="88"/>
        <source>To install unsigned apps, go to Security Center &gt; Tools &gt; App Security, and select the app types that can be installed.</source>
        <translation>Untuk memasang apl tiada tandatangan, pergi ke Pusat Keselamatan &gt; Alatan &gt; Keselamatan Apl, dan pilih jenis apl yang boleh dipasang.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/settingdialog.cpp" line="90"/>
        <source>Security Center &gt; Tools &gt; App Security</source>
        <translation>Pusat Keselamatan &gt; Alatan &gt; Keselamatan Apl</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/uab/uab_package.cpp" line="54"/>
        <source>The system has not installed Linglong environment, please install it first</source>
        <translation>Sistem tidak memasang linglong environment, sila pasang terlebih dahulu</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="47"/>
        <source>Unable to install</source>
        <translation>Tidak boleh memasang</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="49"/>
        <source>This package does not have a valid digital signature and has been blocked from installing/running. Go to Security Center &gt; Tools &gt; App Security to change the settings.</source>
        <translation>Pakej ini tidak mempunyai tandatangan digital yang sah dan telah disekat daripada pemasangan/dijalankan. Pergi ke Pusat Keselamatan &gt; Alatan &gt; Keselamatan Apl untuk mengubah tetapan ini.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="52"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished">Batal</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/error_notify_dialog_helper.cpp" line="53"/>
        <source>Proceed</source>
        <comment>button</comment>
        <translation>Teruskan</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="282"/>
        <source>Will remove: </source>
        <translation>Akan menghapuskan: </translation>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1035"/>
        <source>Collapse</source>
        <translation>Kuncup</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="519"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1233"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1438"/>
        <source>Reinstall</source>
        <translation>Pasang Semula</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1238"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1443"/>
        <source>Later version installed: %1</source>
        <translation>Versi terkemudian dipasang: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1239"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1444"/>
        <source>Downgrade</source>
        <translation>Nyahtatar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1244"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1449"/>
        <source>Earlier version installed: %1</source>
        <translation>Versi lebih awal dipasang: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1336"/>
        <source>Installing dependencies: %1</source>
        <translation>Memasang dependensi: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1499"/>
        <source>Failed to install %1</source>
        <translation>Gagal memasang %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="244"/>
        <source>Version: </source>
        <translation>Versi:</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="190"/>
        <source>Select a compatibility mode:</source>
        <translation>Pilih mod kompatibiliti:</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="511"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>Pasang</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="515"/>
        <source>Remove</source>
        <comment>button</comment>
        <translation>Buang</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="523"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="527"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>Undur</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="531"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>Selesai</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="777"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="818"/>
        <source>Trying to install %2 in %1 compatibility mode</source>
        <translation>Mencuba memasang %2 dalam mod kompatibiliti %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="858"/>
        <source>Uninstalling %2 from %1 compatibility mode</source>
        <translation>Menguninstall %2 dari mod kompatibiliti %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="987"/>
        <source>%2 was successfully installed to %1 compatibility mode</source>
        <translation>%2 telah dipasang dengan jayanya ke dalam mod kompatibiliti %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="991"/>
        <source>Installed successfully</source>
        <translation>Berjaya dipasang</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1000"/>
        <source>%2 has been successfully uninstalled from %1 compatibility mode</source>
        <translation>%2 telah diuninstall dengan jayanya dari mod kompatibiliti %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1004"/>
        <source>Uninstalled successfully</source>
        <translation>Berjaya dinyahpasang</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1024"/>
        <source>Uninstall Failed</source>
        <translation>Nyahpasang Gagal</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1070"/>
        <source>Install %1 will remove: </source>
        <translation>Pemasangan %1 akan menghapuskan: </translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1091"/>
        <source>Dependencies in the repository</source>
        <translation>Dependensi dalam repositori</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1098"/>
        <source>Missing dependencies</source>
        <translation>Dependensi hilang</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1245"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1450"/>
        <source>Update</source>
        <comment>button</comment>
        <translation>Kemas kini</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1505"/>
        <source>Invalid digital signature</source>
        <translation>Tandatangan digital tidak sah</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="232"/>
        <source>Name: </source>
        <translation>Nama:</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1232"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1437"/>
        <source>Same version installed</source>
        <translation>Versi serupa telah dipasang</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage_Install</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="50"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="762"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="803"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="984"/>
        <source>Show details</source>
        <translation>Tunjuk perincian</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="32"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="51"/>
        <source>Show dependencies</source>
        <translation>Tunjuk dependensi</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage_Uninstall</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="843"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="997"/>
        <source>Show details</source>
        <translation>Tunjuk perincian</translation>
    </message>
</context>
<context>
    <name>Uab::UabPackageListModel</name>
    <message>
        <location filename="../src/deb-installer/uab/uab_package_list_model.cpp" line="557"/>
        <source>Installation Failed</source>
        <translation>Pemasangan Gagal</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="17"/>
        <source>Show related packages</source>
        <translation>Tunjuk pakej-pakej berkaitan</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="17"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>Kuncup</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="39"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Batal</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="41"/>
        <source>Confirm</source>
        <translation>Sahkan</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="131"/>
        <source>Are you sure you want to uninstall %1?
All dependencies will also be removed</source>
        <translation>Anda pasti mahu menyahpasang %1?
Semua dependensinya juga akan dibuang</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="133"/>
        <source>Are you sure you want to uninstall %1?
The system or other applications may not work properly</source>
        <translation>Anda pasti mahu menyahpasang %1?
Sistem atau lain-lain aplikasi mungkin tidak berfungsi dengan baik</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="177"/>
        <source>Are you sure you want to uninstall %2 
from %1 compatibility mode?</source>
        <translation>Adakah anda pasti ingin menguninstall %2 dari mod kompatibiliti %1?</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/deb-installer/main.cpp" line="48"/>
        <location filename="../src/deb-installer/main.cpp" line="49"/>
        <source>Package Installer</source>
        <translation>Pemasang Pakej</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/main.cpp" line="50"/>
        <source>Package Installer helps users install and remove local packages, and supports bulk installation.</source>
        <translation>Pemasang pakej dapat membantu pengguna dan membuang pakej-pakej setempat, dan juga menyokong pemasangan pukal.</translation>
    </message>
</context>
</TS>
